@@ -31,7 +31,7 @@
 //! [`embedded-can`]: https://docs.rs/embedded-can
 //! [`defmt`]: https://docs.rs/defmt
 
-#![doc(html_root_url = "https://docs.rs/bxcan/0.6.0")]
+#![doc(html_root_url = "https://docs.rs/bxcan/0.6.2")]
 // Deny a few warnings in doctests, since rustdoc `allow`s many warnings by default
 #![doc(test(attr(deny(unused_imports, unused_must_use))))]
 #![no_std]
@@ -452,9 +452,23 @@ where
 {
     /// Creates a [`CanBuilder`] for constructing a CAN interface.
     pub fn builder(instance: I) -> CanBuilder<I> {
-        CanBuilder {
+        let can_builder = CanBuilder {
             can: Can { instance },
+        };
+
+        let can_reg = can_builder.can.registers();
+        // Enter init mode.
+        can_reg
+            .mcr
+            .modify(|_, w| w.sleep().clear_bit().inrq().set_bit());
+        loop {
+            let msr = can_reg.msr.read();
+            if msr.slak().bit_is_clear() && msr.inak().bit_is_set() {
+                break;
+            }
         }
+
+        can_builder
     }
 
     fn registers(&self) -> &RegisterBlock {
